pub struct ACCESS;Expand description
Accessibility service.
Implementations
Sourceimpl ACCESS
impl ACCESS
Sourcepub fn click(&self, widget: WidgetPath, is_primary: bool)
pub fn click(&self, widget: WidgetPath, is_primary: bool)
Click the widget in the window.
If is_primary is true a primary click is generated, if it is false a context click is generated.
Sourcepub fn show_tooltip(&self, widget: WidgetPath)
pub fn show_tooltip(&self, widget: WidgetPath)
Show tooltip for widget in the window, if it has any tooltip.
The tooltip can auto-hide following the same rules as tooltips shown by hover.
Sourcepub fn hide_tooltip(&self, widget: WidgetPath)
pub fn hide_tooltip(&self, widget: WidgetPath)
Hide tooltip for the widget in the window, if it has any tooltip showing.