pub struct AccessExpanderArgs {
pub timestamp: DInstant,
pub target: WidgetPath,
pub expanded: bool,
pub propagation: EventPropagationHandle,
}Expand description
Arguments for the ACCESS_EXPANDER_EVENT.
Fields
timestamp: DInstantInstant the event happened.
target: WidgetPathTarget.
expanded: boolNew expanded value.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations
Sourceimpl AccessExpanderArgs
impl AccessExpanderArgs
Sourcepub fn new(
timestamp: impl Into<DInstant>,
propagation: EventPropagationHandle,
target: impl Into<WidgetPath>,
expanded: impl Into<bool>,
) -> Self
pub fn new( timestamp: impl Into<DInstant>, propagation: EventPropagationHandle, target: impl Into<WidgetPath>, expanded: impl Into<bool>, ) -> Self
New args from values that convert into the argument types.