pub struct AccessFocusArgs {
pub timestamp: DInstant,
pub target: WidgetPath,
pub focus: bool,
pub propagation: EventPropagationHandle,
}Expand description
Arguments for the ACCESS_FOCUS_EVENT.
Fields
timestamp: DInstantInstant the event happened.
target: WidgetPathTarget.
focus: boolIf the widget must be focused.
If true the widget is focused, if false and the widget is focused, does ESC.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations
Sourceimpl AccessFocusArgs
impl AccessFocusArgs
Sourcepub fn new(
timestamp: impl Into<DInstant>,
propagation: EventPropagationHandle,
target: impl Into<WidgetPath>,
focus: impl Into<bool>,
) -> Self
pub fn new( timestamp: impl Into<DInstant>, propagation: EventPropagationHandle, target: impl Into<WidgetPath>, focus: impl Into<bool>, ) -> Self
New args from values that convert into the argument types.