pub struct AccessFocusNavOriginArgs {
pub timestamp: DInstant,
pub target: WidgetPath,
pub propagation: EventPropagationHandle,
}Expand description
Arguments for the ACCESS_FOCUS_NAV_ORIGIN_EVENT.
Fields
timestamp: DInstantInstant the event happened.
target: WidgetPathTarget.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations
Sourcepub fn new(
timestamp: impl Into<DInstant>,
propagation: EventPropagationHandle,
target: impl Into<WidgetPath>,
) -> Self
pub fn new( timestamp: impl Into<DInstant>, propagation: EventPropagationHandle, target: impl Into<WidgetPath>, ) -> Self
New args from values that convert into the argument types.
Sourcepub fn now(target: impl Into<WidgetPath>) -> Self
pub fn now(target: impl Into<WidgetPath>) -> Self
Arguments for event that happened now (INSTANT.now).