pub struct AccessInitedArgs {
pub timestamp: DInstant,
pub window_id: WindowId,
pub propagation: EventPropagationHandle,
}Expand description
Arguments for the ACCESS_INITED_EVENT.
Fields
timestamp: DInstantInstant the event happened.
window_id: WindowIdTarget window.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations