pub struct AccessScrollArgs {
pub timestamp: DInstant,
pub target: WidgetPath,
pub command: ScrollCmd,
pub propagation: EventPropagationHandle,
}Expand description
Arguments for the ACCESS_SCROLL_EVENT.
Fields
timestamp: DInstantInstant the event happened.
target: WidgetPathTarget.
command: ScrollCmdScroll command.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations
Sourceimpl AccessScrollArgs
impl AccessScrollArgs
Sourcepub fn new(
timestamp: impl Into<DInstant>,
propagation: EventPropagationHandle,
target: impl Into<WidgetPath>,
command: impl Into<ScrollCmd>,
) -> Self
pub fn new( timestamp: impl Into<DInstant>, propagation: EventPropagationHandle, target: impl Into<WidgetPath>, command: impl Into<ScrollCmd>, ) -> Self
New args from values that convert into the argument types.