pub struct AccessSelectionArgs {
pub timestamp: DInstant,
pub start: (WidgetPath, usize),
pub caret: (WidgetPath, usize),
pub propagation: EventPropagationHandle,
}Expand description
Arguments for the ACCESS_SELECTION_EVENT.
Fields
timestamp: DInstantInstant the event happened.
start: (WidgetPath, usize)Selection start.
Text widget and character index where the selection starts.
caret: (WidgetPath, usize)Selection end.
This is where the caret is placed, it does not need to be greater than the start.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations
Sourceimpl AccessSelectionArgs
impl AccessSelectionArgs
Sourcepub fn new(
timestamp: impl Into<DInstant>,
propagation: EventPropagationHandle,
start: impl Into<(WidgetPath, usize)>,
caret: impl Into<(WidgetPath, usize)>,
) -> Self
pub fn new( timestamp: impl Into<DInstant>, propagation: EventPropagationHandle, start: impl Into<(WidgetPath, usize)>, caret: impl Into<(WidgetPath, usize)>, ) -> Self
New args from values that convert into the argument types.
Sourcepub fn now(
start: impl Into<(WidgetPath, usize)>,
caret: impl Into<(WidgetPath, usize)>,
) -> Self
pub fn now( start: impl Into<(WidgetPath, usize)>, caret: impl Into<(WidgetPath, usize)>, ) -> Self
Arguments for event that happened now (INSTANT.now).