pub struct AccessToolTipArgs {
pub timestamp: DInstant,
pub target: WidgetPath,
pub visible: bool,
pub propagation: EventPropagationHandle,
}Expand description
Arguments for the ACCESS_TOOLTIP_EVENT.
Fields
timestamp: DInstantInstant the event happened.
target: WidgetPathTarget.
visible: boolNew tooltip visibility.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations
Sourceimpl AccessToolTipArgs
impl AccessToolTipArgs
Sourcepub fn new(
timestamp: impl Into<DInstant>,
propagation: EventPropagationHandle,
target: impl Into<WidgetPath>,
visible: impl Into<bool>,
) -> Self
pub fn new( timestamp: impl Into<DInstant>, propagation: EventPropagationHandle, target: impl Into<WidgetPath>, visible: impl Into<bool>, ) -> Self
New args from values that convert into the argument types.