pub struct EVENTS;Expand description
App events and commands service.
Implementations
Sourceimpl EVENTS
impl EVENTS
Sourcepub fn commands(&self) -> CommandSet
pub fn commands(&self) -> CommandSet
Commands that had handles generated in this app.
When Command::subscribe is called for the first time in an app, the command gets added
to this list after the current update, if the command is app scoped it remains on the list for
the lifetime of the app, if it is window or widget scoped it only remains while there are handles.
Sourcepub fn notify(
&self,
debug_name: &'static str,
n: impl FnOnce() + Send + 'static,
)
pub fn notify( &self, debug_name: &'static str, n: impl FnOnce() + Send + 'static, )
Schedule a custom closure to run as an event notify callback.
The closure n will run after the current update, any event it notifies will update on the next cycle.
Note that this is just an alias for VARS::modify, events are just an specialized variable.