pub struct PointerMotionArgs {
pub timestamp: DInstant,
pub device_id: InputDeviceId,
pub delta: Vector2D<f64, ()>,
pub propagation: EventPropagationHandle,
}Expand description
Arguments for POINTER_MOTION_EVENT.
Fields
timestamp: DInstantInstant the event happened.
device_id: InputDeviceIdDevice that generated the event.
delta: Vector2D<f64, ()>Motion (x, y) delta.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations
Sourceimpl PointerMotionArgs
impl PointerMotionArgs