pub struct ScrollMotionArgs {
pub timestamp: DInstant,
pub device_id: InputDeviceId,
pub delta: MouseScrollDelta,
pub propagation: EventPropagationHandle,
}Expand description
Arguments for SCROLL_MOTION_EVENT.
Fields
timestamp: DInstantInstant the event happened.
device_id: InputDeviceIdDevice that generated the event.
delta: MouseScrollDeltaWheel motion delta, value is in pixels if the wheel is a touchpad.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations
Sourceimpl ScrollMotionArgs
impl ScrollMotionArgs
Sourcepub fn new(
timestamp: impl Into<DInstant>,
propagation: EventPropagationHandle,
device_id: impl Into<InputDeviceId>,
delta: impl Into<MouseScrollDelta>,
) -> Self
pub fn new( timestamp: impl Into<DInstant>, propagation: EventPropagationHandle, device_id: impl Into<InputDeviceId>, delta: impl Into<MouseScrollDelta>, ) -> Self
New args from values that convert into the argument types.
Sourcepub fn now(
device_id: impl Into<InputDeviceId>,
delta: impl Into<MouseScrollDelta>,
) -> Self
pub fn now( device_id: impl Into<InputDeviceId>, delta: impl Into<MouseScrollDelta>, ) -> Self
Arguments for event that happened now (INSTANT.now).