pub struct LowMemoryArgs {
pub timestamp: DInstant,
pub propagation: EventPropagationHandle,
}Expand description
Arguments for LOW_MEMORY_EVENT.
Fields
timestamp: DInstantInstant the event happened.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations