pub struct RawAnimationsConfigChangedArgs {
pub timestamp: DInstant,
pub config: AnimationsConfig,
pub propagation: EventPropagationHandle,
}Expand description
Arguments for the RAW_ANIMATIONS_CONFIG_CHANGED_EVENT.
Fields
timestamp: DInstantInstant the event happened.
config: AnimationsConfigNew config.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations
Sourceimpl RawAnimationsConfigChangedArgs
impl RawAnimationsConfigChangedArgs
Sourcepub fn new(
timestamp: impl Into<DInstant>,
propagation: EventPropagationHandle,
config: impl Into<AnimationsConfig>,
) -> Self
pub fn new( timestamp: impl Into<DInstant>, propagation: EventPropagationHandle, config: impl Into<AnimationsConfig>, ) -> Self
New args from values that convert into the argument types.
Sourcepub fn now(config: impl Into<AnimationsConfig>) -> Self
pub fn now(config: impl Into<AnimationsConfig>) -> Self
Arguments for event that happened now (INSTANT.now).