pub struct RawAppDragEndedArgs {
pub timestamp: DInstant,
pub window_id: WindowId,
pub id: DragDropId,
pub applied: DragDropEffect,
pub propagation: EventPropagationHandle,
}Expand description
Arguments for the RAW_APP_DRAG_ENDED_EVENT.
Fields
timestamp: DInstantInstant the event happened.
window_id: WindowIdWindow that started the drag operation.
id: DragDropIdID of the drag & drop operation.
applied: DragDropEffectEffect applied to the data by the drop target.
Is a single flag if the data was dropped in a valid drop target, or is empty if was canceled.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations
Sourceimpl RawAppDragEndedArgs
impl RawAppDragEndedArgs
Sourcepub fn new(
timestamp: impl Into<DInstant>,
propagation: EventPropagationHandle,
window_id: impl Into<WindowId>,
id: impl Into<DragDropId>,
applied: impl Into<DragDropEffect>,
) -> Self
pub fn new( timestamp: impl Into<DInstant>, propagation: EventPropagationHandle, window_id: impl Into<WindowId>, id: impl Into<DragDropId>, applied: impl Into<DragDropEffect>, ) -> Self
New args from values that convert into the argument types.
Sourcepub fn now(
window_id: impl Into<WindowId>,
id: impl Into<DragDropId>,
applied: impl Into<DragDropEffect>,
) -> Self
pub fn now( window_id: impl Into<WindowId>, id: impl Into<DragDropId>, applied: impl Into<DragDropEffect>, ) -> Self
Arguments for event that happened now (INSTANT.now).