pub struct RawAudioDecodeErrorArgs {
pub timestamp: DInstant,
pub handle: WeakViewAudioHandle,
pub error: Txt,
pub propagation: EventPropagationHandle,
}Expand description
Arguments for the RAW_AUDIO_DECODE_ERROR_EVENT.
Fields
timestamp: DInstantInstant the event happened.
handle: WeakViewAudioHandleHandle that identifies the audio request.
The audio data is already removed in the view-process.
The handle can be upgraded on hook only, after it is dropped. This is so the latest event does not keep the audio alive indefinitely.
error: TxtError message.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations
Sourceimpl RawAudioDecodeErrorArgs
impl RawAudioDecodeErrorArgs
Sourcepub fn new(
timestamp: impl Into<DInstant>,
propagation: EventPropagationHandle,
handle: impl Into<WeakViewAudioHandle>,
error: impl Into<Txt>,
) -> Self
pub fn new( timestamp: impl Into<DInstant>, propagation: EventPropagationHandle, handle: impl Into<WeakViewAudioHandle>, error: impl Into<Txt>, ) -> Self
New args from values that convert into the argument types.