pub struct RawAudioDecodedArgs {
pub timestamp: DInstant,
pub handle: WeakViewAudioHandle,
pub audio: WeakEq<AudioDecoded>,
pub propagation: EventPropagationHandle,
}Expand description
Arguments for the RAW_AUDIO_DECODED_EVENT.
Fields
timestamp: DInstantInstant the event happened.
handle: WeakViewAudioHandleHandle to the audio in the view-process. The handle can be upgraded on hook only, after it is dropped. This is so the latest event does not keep the audio alive indefinitely.
audio: WeakEq<AudioDecoded>Audio data.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations
Sourceimpl RawAudioDecodedArgs
impl RawAudioDecodedArgs
Sourcepub fn new(
timestamp: impl Into<DInstant>,
propagation: EventPropagationHandle,
handle: impl Into<WeakViewAudioHandle>,
audio: impl Into<WeakEq<AudioDecoded>>,
) -> Self
pub fn new( timestamp: impl Into<DInstant>, propagation: EventPropagationHandle, handle: impl Into<WeakViewAudioHandle>, audio: impl Into<WeakEq<AudioDecoded>>, ) -> Self
New args from values that convert into the argument types.
Sourcepub fn now(
handle: impl Into<WeakViewAudioHandle>,
audio: impl Into<WeakEq<AudioDecoded>>,
) -> Self
pub fn now( handle: impl Into<WeakViewAudioHandle>, audio: impl Into<WeakEq<AudioDecoded>>, ) -> Self
Arguments for event that happened now (INSTANT.now).