pub struct RawAudioOutputOpenArgs {
pub timestamp: DInstant,
pub output_id: AudioOutputId,
pub output: WeakViewAudioOutput,
pub propagation: EventPropagationHandle,
}Expand description
Arguments for the RAW_AUDIO_OUTPUT_OPEN_EVENT.
Fields
timestamp: DInstantInstant the event happened.
output_id: AudioOutputIdOutput that finished opening.
output: WeakViewAudioOutputLive connection to audio output stream.
The handle can be upgraded on hook only, after it is dropped. This is so the latest event does not keep the image audio indefinitely.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations
Sourceimpl RawAudioOutputOpenArgs
impl RawAudioOutputOpenArgs
Sourcepub fn new(
timestamp: impl Into<DInstant>,
propagation: EventPropagationHandle,
output_id: impl Into<AudioOutputId>,
output: impl Into<WeakViewAudioOutput>,
) -> Self
pub fn new( timestamp: impl Into<DInstant>, propagation: EventPropagationHandle, output_id: impl Into<AudioOutputId>, output: impl Into<WeakViewAudioOutput>, ) -> Self
New args from values that convert into the argument types.
Sourcepub fn now(
output_id: impl Into<AudioOutputId>,
output: impl Into<WeakViewAudioOutput>,
) -> Self
pub fn now( output_id: impl Into<AudioOutputId>, output: impl Into<WeakViewAudioOutput>, ) -> Self
Arguments for event that happened now (INSTANT.now).