pub struct RawAudioOutputOpenErrorArgs {
pub timestamp: DInstant,
pub output_id: AudioOutputId,
pub error: Txt,
pub propagation: EventPropagationHandle,
}Expand description
Arguments for the RAW_AUDIO_OUTPUT_OPEN_ERROR_EVENT.
Fields
timestamp: DInstantInstant the event happened.
output_id: AudioOutputIdOutput that failed to open.
error: TxtError opening output.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations
Sourceimpl RawAudioOutputOpenErrorArgs
impl RawAudioOutputOpenErrorArgs
Sourcepub fn new(
timestamp: impl Into<DInstant>,
propagation: EventPropagationHandle,
output_id: impl Into<AudioOutputId>,
error: impl Into<Txt>,
) -> Self
pub fn new( timestamp: impl Into<DInstant>, propagation: EventPropagationHandle, output_id: impl Into<AudioOutputId>, error: impl Into<Txt>, ) -> Self
New args from values that convert into the argument types.