pub struct RawAxisMotionArgs {
pub timestamp: DInstant,
pub window_id: WindowId,
pub device_id: InputDeviceId,
pub axis: AxisId,
pub value: f64,
pub propagation: EventPropagationHandle,
}Expand description
Arguments for the RAW_AXIS_MOTION_EVENT.
Fields
timestamp: DInstantInstant the event happened.
window_id: WindowIdWindow that received the event.
device_id: InputDeviceIdDevice that generated the event.
axis: AxisIdAnalog axis.
value: f64Motion amount.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations
Sourceimpl RawAxisMotionArgs
impl RawAxisMotionArgs