pub struct RawColorsConfigChangedArgs {
pub timestamp: DInstant,
pub config: ColorsConfig,
pub propagation: EventPropagationHandle,
}Expand description
Arguments for the RAW_COLORS_CONFIG_CHANGED_EVENT.
Fields
timestamp: DInstantInstant the event happened.
config: ColorsConfigNew config.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations
Sourceimpl RawColorsConfigChangedArgs
impl RawColorsConfigChangedArgs
Sourcepub fn new(
timestamp: impl Into<DInstant>,
propagation: EventPropagationHandle,
config: impl Into<ColorsConfig>,
) -> Self
pub fn new( timestamp: impl Into<DInstant>, propagation: EventPropagationHandle, config: impl Into<ColorsConfig>, ) -> Self
New args from values that convert into the argument types.
Sourcepub fn now(config: impl Into<ColorsConfig>) -> Self
pub fn now(config: impl Into<ColorsConfig>) -> Self
Arguments for event that happened now (INSTANT.now).