pub struct RawDragCancelledArgs {
pub timestamp: DInstant,
pub window_id: WindowId,
pub propagation: EventPropagationHandle,
}Expand description
Arguments for the RAW_DRAG_CANCELLED_EVENT.
Fields
timestamp: DInstantInstant the event happened.
window_id: WindowIdWindow where the file was previously dragged over.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations