pub struct RawDragDroppedArgs {
pub timestamp: DInstant,
pub window_id: WindowId,
pub data: Vec<DragDropData>,
pub allowed: DragDropEffect,
pub drop_id: DragDropId,
pub propagation: EventPropagationHandle,
}Expand description
Arguments for the RAW_DRAG_DROPPED_EVENT.
Fields
timestamp: DInstantInstant the event happened.
window_id: WindowIdWindow where it was dropped.
data: Vec<DragDropData>Data payload.
allowed: DragDropEffectAllowed effects.
drop_id: DragDropIdID of this drop operation.
Handlers must call drag_dropped with this ID and what effect was applied to the data.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations
Sourceimpl RawDragDroppedArgs
impl RawDragDroppedArgs
Sourcepub fn new(
timestamp: impl Into<DInstant>,
propagation: EventPropagationHandle,
window_id: impl Into<WindowId>,
data: impl Into<Vec<DragDropData>>,
allowed: impl Into<DragDropEffect>,
drop_id: impl Into<DragDropId>,
) -> Self
pub fn new( timestamp: impl Into<DInstant>, propagation: EventPropagationHandle, window_id: impl Into<WindowId>, data: impl Into<Vec<DragDropData>>, allowed: impl Into<DragDropEffect>, drop_id: impl Into<DragDropId>, ) -> Self
New args from values that convert into the argument types.
Sourcepub fn now(
window_id: impl Into<WindowId>,
data: impl Into<Vec<DragDropData>>,
allowed: impl Into<DragDropEffect>,
drop_id: impl Into<DragDropId>,
) -> Self
pub fn now( window_id: impl Into<WindowId>, data: impl Into<Vec<DragDropData>>, allowed: impl Into<DragDropEffect>, drop_id: impl Into<DragDropId>, ) -> Self
Arguments for event that happened now (INSTANT.now).