pub struct RawDragHoveredArgs {
pub timestamp: DInstant,
pub window_id: WindowId,
pub data: Vec<DragDropData>,
pub allowed: DragDropEffect,
pub propagation: EventPropagationHandle,
}Expand description
Arguments for the RAW_DRAG_HOVERED_EVENT.
Fields
timestamp: DInstantInstant the event happened.
window_id: WindowIdWindow where it was dragged over.
data: Vec<DragDropData>Data payload.
allowed: DragDropEffectAllowed effects.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations
Sourceimpl RawDragHoveredArgs
impl RawDragHoveredArgs
Sourcepub fn new(
timestamp: impl Into<DInstant>,
propagation: EventPropagationHandle,
window_id: impl Into<WindowId>,
data: impl Into<Vec<DragDropData>>,
allowed: impl Into<DragDropEffect>,
) -> Self
pub fn new( timestamp: impl Into<DInstant>, propagation: EventPropagationHandle, window_id: impl Into<WindowId>, data: impl Into<Vec<DragDropData>>, allowed: impl Into<DragDropEffect>, ) -> Self
New args from values that convert into the argument types.
Sourcepub fn now(
window_id: impl Into<WindowId>,
data: impl Into<Vec<DragDropData>>,
allowed: impl Into<DragDropEffect>,
) -> Self
pub fn now( window_id: impl Into<WindowId>, data: impl Into<Vec<DragDropData>>, allowed: impl Into<DragDropEffect>, ) -> Self
Arguments for event that happened now (INSTANT.now).