pub struct RawDragMovedArgs {
pub timestamp: DInstant,
pub window_id: WindowId,
pub coalesced_pos: Vec<DipPoint>,
pub position: DipPoint,
pub propagation: EventPropagationHandle,
}Expand description
Arguments for the RAW_DRAG_MOVED_EVENT.
Fields
timestamp: DInstantInstant the event happened.
window_id: WindowIdWindow that is hovered by drag&drop.
coalesced_pos: Vec<DipPoint>Cursor positions in between the previous event and this one.
Drag move events can be coalesced, i.e. multiple moves packed into a single event.
position: DipPointPosition of the cursor over the window, (0, 0) is the top-left.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations