pub struct RawExtensionEventArgs {
pub timestamp: DInstant,
pub extension_id: ApiExtensionId,
pub payload: ApiExtensionPayload,
pub propagation: EventPropagationHandle,
}Expand description
Arguments for the RAW_EXTENSION_EVENT.
Fields
timestamp: DInstantInstant the event happened.
extension_id: ApiExtensionIdId of the sender extension.
payload: ApiExtensionPayloadEvent payload.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations
Sourceimpl RawExtensionEventArgs
impl RawExtensionEventArgs
Sourcepub fn new(
timestamp: impl Into<DInstant>,
propagation: EventPropagationHandle,
extension_id: impl Into<ApiExtensionId>,
payload: impl Into<ApiExtensionPayload>,
) -> Self
pub fn new( timestamp: impl Into<DInstant>, propagation: EventPropagationHandle, extension_id: impl Into<ApiExtensionId>, payload: impl Into<ApiExtensionPayload>, ) -> Self
New args from values that convert into the argument types.
Sourcepub fn now(
extension_id: impl Into<ApiExtensionId>,
payload: impl Into<ApiExtensionPayload>,
) -> Self
pub fn now( extension_id: impl Into<ApiExtensionId>, payload: impl Into<ApiExtensionPayload>, ) -> Self
Arguments for event that happened now (INSTANT.now).