pub struct RawFontAaChangedArgs {
pub timestamp: DInstant,
pub aa: FontAntiAliasing,
pub propagation: EventPropagationHandle,
}Expand description
Arguments for the RAW_FONT_AA_CHANGED_EVENT.
Fields
timestamp: DInstantInstant the event happened.
aa: FontAntiAliasingThe new anti-aliasing config.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations
Sourceimpl RawFontAaChangedArgs
impl RawFontAaChangedArgs
Sourcepub fn new(
timestamp: impl Into<DInstant>,
propagation: EventPropagationHandle,
aa: impl Into<FontAntiAliasing>,
) -> Self
pub fn new( timestamp: impl Into<DInstant>, propagation: EventPropagationHandle, aa: impl Into<FontAntiAliasing>, ) -> Self
New args from values that convert into the argument types.
Sourcepub fn now(aa: impl Into<FontAntiAliasing>) -> Self
pub fn now(aa: impl Into<FontAntiAliasing>) -> Self
Arguments for event that happened now (INSTANT.now).