RawHeadlessOpenArgs

Struct RawHeadlessOpenArgs 

pub struct RawHeadlessOpenArgs {
    pub timestamp: DInstant,
    pub window_id: WindowId,
    pub surface: WeakViewHeadless,
    pub data: HeadlessOpenData,
    pub propagation: EventPropagationHandle,
}
Arguments for the RAW_HEADLESS_OPEN_EVENT.

Fields

timestamp: DInstant

Instant the event happened.

window_id: WindowId

Window id that represents the headless surface that finished opening.

surface: WeakViewHeadless

Live connection to the headless surface in the view-process.

The handle can be upgraded on hook only, after it is dropped. This is so the latest event does not keep the surface alive indefinitely.

data: HeadlessOpenData

Extra data send by the view-process.

propagation: EventPropagationHandle

Propagation handle associated with this event instance.

Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.

Implementations

Source

impl RawHeadlessOpenArgs

pub fn new( timestamp: impl Into<DInstant>, propagation: EventPropagationHandle, window_id: impl Into<WindowId>, surface: impl Into<WeakViewHeadless>, data: impl Into<HeadlessOpenData>, ) -> Self

New args from values that convert into the argument types.

pub fn now( window_id: impl Into<WindowId>, surface: impl Into<WeakViewHeadless>, data: impl Into<HeadlessOpenData>, ) -> Self

Arguments for event that happened now (INSTANT.now).