pub struct RawImageDecodeErrorArgs {
pub timestamp: DInstant,
pub handle: WeakViewImageHandle,
pub error: Txt,
pub propagation: EventPropagationHandle,
}Expand description
Arguments for the RAW_IMAGE_DECODE_ERROR_EVENT.
Fields
timestamp: DInstantInstant the event happened.
handle: WeakViewImageHandleHandle that identifies the image request.
The image data is already removed in the view-process.
The handle can be upgraded on hook only, after it is dropped.
error: TxtError message.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations
Sourceimpl RawImageDecodeErrorArgs
impl RawImageDecodeErrorArgs
Sourcepub fn new(
timestamp: impl Into<DInstant>,
propagation: EventPropagationHandle,
handle: impl Into<WeakViewImageHandle>,
error: impl Into<Txt>,
) -> Self
pub fn new( timestamp: impl Into<DInstant>, propagation: EventPropagationHandle, handle: impl Into<WeakViewImageHandle>, error: impl Into<Txt>, ) -> Self
New args from values that convert into the argument types.