pub struct RawImageDecodedArgs {
pub timestamp: DInstant,
pub handle: WeakViewImageHandle,
pub image: WeakEq<ImageDecoded>,
pub propagation: EventPropagationHandle,
}Expand description
Arguments for the RAW_IMAGE_DECODED_EVENT.
Fields
timestamp: DInstantInstant the event happened.
handle: WeakViewImageHandleHandle to the image in the view-process.
The handle can be upgraded on hook only, after it is dropped. This is so the latest event does not keep the image alive indefinitely.
image: WeakEq<ImageDecoded>Image data.
The handle can be upgraded on hook only, after it is dropped.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations
Sourceimpl RawImageDecodedArgs
impl RawImageDecodedArgs
Sourcepub fn new(
timestamp: impl Into<DInstant>,
propagation: EventPropagationHandle,
handle: impl Into<WeakViewImageHandle>,
image: impl Into<WeakEq<ImageDecoded>>,
) -> Self
pub fn new( timestamp: impl Into<DInstant>, propagation: EventPropagationHandle, handle: impl Into<WeakViewImageHandle>, image: impl Into<WeakEq<ImageDecoded>>, ) -> Self
New args from values that convert into the argument types.
Sourcepub fn now(
handle: impl Into<WeakViewImageHandle>,
image: impl Into<WeakEq<ImageDecoded>>,
) -> Self
pub fn now( handle: impl Into<WeakViewImageHandle>, image: impl Into<WeakEq<ImageDecoded>>, ) -> Self
Arguments for event that happened now (INSTANT.now).