pub struct RawImageMetadataDecodedArgs {
pub timestamp: DInstant,
pub handle: WeakViewImageHandle,
pub meta: ImageMetadata,
pub propagation: EventPropagationHandle,
}Expand description
Arguments for RAW_IMAGE_METADATA_DECODED_EVENT.
Fields
timestamp: DInstantInstant the event happened.
handle: WeakViewImageHandleHandle to the image in the view-process.
The handle can be upgraded on hook only, after it is dropped. This is so the latest event does not keep the image alive indefinitely.
meta: ImageMetadataImage metadata.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations
Sourceimpl RawImageMetadataDecodedArgs
impl RawImageMetadataDecodedArgs
Sourcepub fn new(
timestamp: impl Into<DInstant>,
propagation: EventPropagationHandle,
handle: impl Into<WeakViewImageHandle>,
meta: impl Into<ImageMetadata>,
) -> Self
pub fn new( timestamp: impl Into<DInstant>, propagation: EventPropagationHandle, handle: impl Into<WeakViewImageHandle>, meta: impl Into<ImageMetadata>, ) -> Self
New args from values that convert into the argument types.
Sourcepub fn now(
handle: impl Into<WeakViewImageHandle>,
meta: impl Into<ImageMetadata>,
) -> Self
pub fn now( handle: impl Into<WeakViewImageHandle>, meta: impl Into<ImageMetadata>, ) -> Self
Arguments for event that happened now (INSTANT.now).