pub struct RawImeArgs {
pub timestamp: DInstant,
pub window_id: WindowId,
pub ime: Ime,
pub propagation: EventPropagationHandle,
}Expand description
Arguments for the RAW_IME_EVENT.
Fields
timestamp: DInstantInstant the event happened.
window_id: WindowIdWindow that received the event.
ime: ImeThe IME event.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations