pub struct RawKeyRepeatConfigChangedArgs {
pub timestamp: DInstant,
pub config: KeyRepeatConfig,
pub propagation: EventPropagationHandle,
}Expand description
Arguments for the RAW_KEY_REPEAT_CONFIG_CHANGED_EVENT.
Fields
timestamp: DInstantInstant the event happened.
config: KeyRepeatConfigNew config.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations
Sourceimpl RawKeyRepeatConfigChangedArgs
impl RawKeyRepeatConfigChangedArgs
Sourcepub fn new(
timestamp: impl Into<DInstant>,
propagation: EventPropagationHandle,
config: impl Into<KeyRepeatConfig>,
) -> Self
pub fn new( timestamp: impl Into<DInstant>, propagation: EventPropagationHandle, config: impl Into<KeyRepeatConfig>, ) -> Self
New args from values that convert into the argument types.
Sourcepub fn now(config: impl Into<KeyRepeatConfig>) -> Self
pub fn now(config: impl Into<KeyRepeatConfig>) -> Self
Arguments for event that happened now (INSTANT.now).