pub struct RawMouseArgs {
pub timestamp: DInstant,
pub window_id: WindowId,
pub device_id: InputDeviceId,
pub propagation: EventPropagationHandle,
}Expand description
Arguments for the RAW_MOUSE_ENTERED_EVENT and RAW_MOUSE_LEFT_EVENT.
Fields
timestamp: DInstantInstant the event happened.
window_id: WindowIdWindow the mouse entered or left.
device_id: InputDeviceIdDevice that generated this event.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations
Sourceimpl RawMouseArgs
impl RawMouseArgs
Sourcepub fn new(
timestamp: impl Into<DInstant>,
propagation: EventPropagationHandle,
window_id: impl Into<WindowId>,
device_id: impl Into<InputDeviceId>,
) -> Self
pub fn new( timestamp: impl Into<DInstant>, propagation: EventPropagationHandle, window_id: impl Into<WindowId>, device_id: impl Into<InputDeviceId>, ) -> Self
New args from values that convert into the argument types.