pub struct RawMouseInputArgs {
pub timestamp: DInstant,
pub window_id: WindowId,
pub device_id: InputDeviceId,
pub state: ButtonState,
pub button: MouseButton,
pub propagation: EventPropagationHandle,
}Expand description
Arguments for the RAW_MOUSE_INPUT_EVENT.
Fields
timestamp: DInstantInstant the event happened.
window_id: WindowIdWindow that is hovered by the mouse.
device_id: InputDeviceIdDevice that generated this event.
state: ButtonStateIf the button was pressed or released.
What button was pressed or released.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations
Sourceimpl RawMouseInputArgs
impl RawMouseInputArgs
Sourcepub fn new(
timestamp: impl Into<DInstant>,
propagation: EventPropagationHandle,
window_id: impl Into<WindowId>,
device_id: impl Into<InputDeviceId>,
state: impl Into<ButtonState>,
button: impl Into<MouseButton>,
) -> Self
pub fn new( timestamp: impl Into<DInstant>, propagation: EventPropagationHandle, window_id: impl Into<WindowId>, device_id: impl Into<InputDeviceId>, state: impl Into<ButtonState>, button: impl Into<MouseButton>, ) -> Self
New args from values that convert into the argument types.
Sourcepub fn now(
window_id: impl Into<WindowId>,
device_id: impl Into<InputDeviceId>,
state: impl Into<ButtonState>,
button: impl Into<MouseButton>,
) -> Self
pub fn now( window_id: impl Into<WindowId>, device_id: impl Into<InputDeviceId>, state: impl Into<ButtonState>, button: impl Into<MouseButton>, ) -> Self
Arguments for event that happened now (INSTANT.now).