RawMouseMovedArgs

Struct RawMouseMovedArgs 

pub struct RawMouseMovedArgs {
    pub timestamp: DInstant,
    pub window_id: WindowId,
    pub device_id: InputDeviceId,
    pub coalesced_pos: Vec<DipPoint>,
    pub position: DipPoint,
    pub propagation: EventPropagationHandle,
}
Arguments for the RAW_MOUSE_MOVED_EVENT.

Fields

timestamp: DInstant

Instant the event happened.

window_id: WindowId

Window the mouse was moved over.

device_id: InputDeviceId

Device that generated this event.

coalesced_pos: Vec<DipPoint>

Positions of the mouse in between the previous event and this one.

Mouse move events can be coalesced, i.e. multiple mouse moves packed into a single event.

position: DipPoint

Position of the mouse over the window, (0, 0) is the top-left.

propagation: EventPropagationHandle

Propagation handle associated with this event instance.

Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.

Implementations

Source

impl RawMouseMovedArgs

pub fn new( timestamp: impl Into<DInstant>, propagation: EventPropagationHandle, window_id: impl Into<WindowId>, device_id: impl Into<InputDeviceId>, coalesced_pos: impl Into<Vec<DipPoint>>, position: impl Into<DipPoint>, ) -> Self

New args from values that convert into the argument types.

pub fn now( window_id: impl Into<WindowId>, device_id: impl Into<InputDeviceId>, coalesced_pos: impl Into<Vec<DipPoint>>, position: impl Into<DipPoint>, ) -> Self

Arguments for event that happened now (INSTANT.now).