pub struct RawScaleFactorChangedArgs {
pub timestamp: DInstant,
pub monitor_id: MonitorId,
pub windows: Vec<WindowId>,
pub scale_factor: Factor,
pub propagation: EventPropagationHandle,
}Expand description
Arguments for the RAW_SCALE_FACTOR_CHANGED_EVENT.
Fields
timestamp: DInstantInstant the event happened.
monitor_id: MonitorIdMonitor that has changed.
windows: Vec<WindowId>Window in the monitor that has changed.
scale_factor: FactorNew pixel scale factor.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations