pub struct RawTouchConfigChangedArgs {
pub timestamp: DInstant,
pub config: TouchConfig,
pub propagation: EventPropagationHandle,
}Expand description
Arguments for the RAW_TOUCH_CONFIG_CHANGED_EVENT.
Fields
timestamp: DInstantInstant the event happened.
config: TouchConfigNew config.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations
Sourceimpl RawTouchConfigChangedArgs
impl RawTouchConfigChangedArgs
Sourcepub fn new(
timestamp: impl Into<DInstant>,
propagation: EventPropagationHandle,
config: impl Into<TouchConfig>,
) -> Self
pub fn new( timestamp: impl Into<DInstant>, propagation: EventPropagationHandle, config: impl Into<TouchConfig>, ) -> Self
New args from values that convert into the argument types.
Sourcepub fn now(config: impl Into<TouchConfig>) -> Self
pub fn now(config: impl Into<TouchConfig>) -> Self
Arguments for event that happened now (INSTANT.now).