pub struct RawTouchpadPressureArgs {
pub timestamp: DInstant,
pub window_id: WindowId,
pub device_id: InputDeviceId,
pub pressure: Factor,
pub stage: i64,
pub propagation: EventPropagationHandle,
}Expand description
Arguments for the RAW_TOUCHPAD_PRESSURE_EVENT.
Fields
timestamp: DInstantInstant the event happened.
window_id: WindowIdWindow that is touched.
device_id: InputDeviceIdDevice that generated this event.
pressure: FactorPressure level between 0 and 1.
stage: i64Click level.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations
Sourceimpl RawTouchpadPressureArgs
impl RawTouchpadPressureArgs