pub struct RawWindowChangedArgs {
pub timestamp: DInstant,
pub window_id: WindowId,
pub state: Option<WindowStateAll>,
pub position: Option<(PxPoint, DipPoint)>,
pub monitor: Option<MonitorId>,
pub size: Option<DipSize>,
pub safe_padding: Option<DipSideOffsets>,
pub cause: EventCause,
pub frame_wait_id: Option<FrameWaitId>,
pub propagation: EventPropagationHandle,
}Expand description
Arguments for the RAW_WINDOW_CHANGED_EVENT.
Fields
timestamp: DInstantInstant the event happened.
window_id: WindowIdWindow that has moved, resized or has a state change.
state: Option<WindowStateAll>New state if any part of it has changed.
position: Option<(PxPoint, DipPoint)>New window position if it was moved.
The values are (global_position, position_in_monitor).
monitor: Option<MonitorId>New window monitor.
The window’s monitor change when it is moved enough so that most of the client area is in the new monitor screen.
size: Option<DipSize>New window size if it was resized.
safe_padding: Option<DipSideOffsets>New window safe padding.
cause: EventCauseIf the app or operating system caused the change.
frame_wait_id: Option<FrameWaitId>If the view-process is blocking the event loop for a time waiting for a frame for the new size this
ID must be send with the frame to signal that it is the frame for the new size.
Event loop implementations can use this to resize without visible artifacts
like the clear color flashing on the window corners, there is a timeout to this delay but it
can be a noticeable stutter, a render or render_update request for the window unblocks the loop early
to continue the resize operation.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations
Sourceimpl RawWindowChangedArgs
impl RawWindowChangedArgs
Sourcepub fn new(
timestamp: impl Into<DInstant>,
propagation: EventPropagationHandle,
window_id: impl Into<WindowId>,
state: impl Into<Option<WindowStateAll>>,
position: impl Into<Option<(PxPoint, DipPoint)>>,
monitor: impl Into<Option<MonitorId>>,
size: impl Into<Option<DipSize>>,
safe_padding: impl Into<Option<DipSideOffsets>>,
cause: impl Into<EventCause>,
frame_wait_id: impl Into<Option<FrameWaitId>>,
) -> Self
pub fn new( timestamp: impl Into<DInstant>, propagation: EventPropagationHandle, window_id: impl Into<WindowId>, state: impl Into<Option<WindowStateAll>>, position: impl Into<Option<(PxPoint, DipPoint)>>, monitor: impl Into<Option<MonitorId>>, size: impl Into<Option<DipSize>>, safe_padding: impl Into<Option<DipSideOffsets>>, cause: impl Into<EventCause>, frame_wait_id: impl Into<Option<FrameWaitId>>, ) -> Self
New args from values that convert into the argument types.
Sourcepub fn now(
window_id: impl Into<WindowId>,
state: impl Into<Option<WindowStateAll>>,
position: impl Into<Option<(PxPoint, DipPoint)>>,
monitor: impl Into<Option<MonitorId>>,
size: impl Into<Option<DipSize>>,
safe_padding: impl Into<Option<DipSideOffsets>>,
cause: impl Into<EventCause>,
frame_wait_id: impl Into<Option<FrameWaitId>>,
) -> Self
pub fn now( window_id: impl Into<WindowId>, state: impl Into<Option<WindowStateAll>>, position: impl Into<Option<(PxPoint, DipPoint)>>, monitor: impl Into<Option<MonitorId>>, size: impl Into<Option<DipSize>>, safe_padding: impl Into<Option<DipSideOffsets>>, cause: impl Into<EventCause>, frame_wait_id: impl Into<Option<FrameWaitId>>, ) -> Self
Arguments for event that happened now (INSTANT.now).