pub struct RawWindowFocusArgs {
pub timestamp: DInstant,
pub prev_focus: Option<WindowId>,
pub new_focus: Option<WindowId>,
pub propagation: EventPropagationHandle,
}Expand description
Arguments for the RAW_WINDOW_FOCUS_EVENT.
Fields
timestamp: DInstantInstant the event happened.
prev_focus: Option<WindowId>Window that load focus.
new_focus: Option<WindowId>Window that got focus.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations