pub struct RawWindowOpenArgs {
pub timestamp: DInstant,
pub window_id: WindowId,
pub window: WeakViewWindow,
pub data: WindowOpenData,
pub propagation: EventPropagationHandle,
}Expand description
Arguments for the RAW_WINDOW_OPEN_EVENT.
Fields
timestamp: DInstantInstant the event happened.
window_id: WindowIdWindow that finished opening.
window: WeakViewWindowLive connection to the window in the view-process.
The handle can be upgraded on hook only, after it is dropped. This is so the latest event does not keep the window alive indefinitely.
data: WindowOpenDataExtra data send by the view-process.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations
Sourceimpl RawWindowOpenArgs
impl RawWindowOpenArgs
Sourcepub fn new(
timestamp: impl Into<DInstant>,
propagation: EventPropagationHandle,
window_id: impl Into<WindowId>,
window: impl Into<WeakViewWindow>,
data: impl Into<WindowOpenData>,
) -> Self
pub fn new( timestamp: impl Into<DInstant>, propagation: EventPropagationHandle, window_id: impl Into<WindowId>, window: impl Into<WeakViewWindow>, data: impl Into<WindowOpenData>, ) -> Self
New args from values that convert into the argument types.
Sourcepub fn now(
window_id: impl Into<WindowId>,
window: impl Into<WeakViewWindow>,
data: impl Into<WindowOpenData>,
) -> Self
pub fn now( window_id: impl Into<WindowId>, window: impl Into<WeakViewWindow>, data: impl Into<WindowOpenData>, ) -> Self
Arguments for event that happened now (INSTANT.now).