pub struct RawWindowOrHeadlessOpenErrorArgs {
pub timestamp: DInstant,
pub window_id: WindowId,
pub error: Txt,
pub propagation: EventPropagationHandle,
}Expand description
Arguments for the RAW_WINDOW_OR_HEADLESS_OPEN_ERROR_EVENT.
Fields
timestamp: DInstantInstant the event happened.
window_id: WindowIdWindow id that failed to open.
error: TxtError message from the view-process.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations