ViewAudioHandle

Struct ViewAudioHandle 

pub struct ViewAudioHandle(/* private fields */);
Handle to an audio loading or loaded in the View Process.

The audio is disposed when all clones of the handle are dropped.

Implementations

Source

impl ViewAudioHandle

pub fn dummy() -> Self

New handle to nothing.

pub fn is_dummy(&self) -> bool

Is handle to nothing.

pub fn audio_id(&self) -> AudioId

Audio ID.

Is AudioId::INVALID for dummy.

pub fn app_id(&self) -> Option<AppId>

Application that requested this image.

Audios can only be used in the same app.

Is None for dummy.

pub fn view_process_gen(&self) -> ViewProcessGen

View-process generation that provided this image.

Audios can only be used in the same view-process instance.

Is ViewProcessGen::INVALID for dummy.

pub fn downgrade(&self) -> WeakViewAudioHandle

Create a weak reference to this audio.