pub struct ViewAudioOutput(/* private fields */);Expand description
Handle to an audio output stream in the View Process.
The stream is disposed when all clones of the handle are dropped.
Implementations
Sourceimpl ViewAudioOutput
impl ViewAudioOutput
Sourcepub fn cue(&self, mix: AudioMix) -> Result<AudioPlayId, ChannelError>
pub fn cue(&self, mix: AudioMix) -> Result<AudioPlayId, ChannelError>
Play or enqueue audio.
Sourcepub fn update(&self, cfg: AudioOutputConfig) -> Result<(), ChannelError>
pub fn update(&self, cfg: AudioOutputConfig) -> Result<(), ChannelError>
Update state, volume, speed.
Sourcepub fn data(&self) -> &AudioOutputOpenData
pub fn data(&self) -> &AudioOutputOpenData
Audio output stream data.
Sourcepub fn downgrade(&self) -> WeakViewAudioOutput
pub fn downgrade(&self) -> WeakViewAudioOutput
Create a weak reference to this audio output.