pub struct ViewImageHandle(/* private fields */);Expand description
Handle to an image loading or loaded in the View Process.
The image is disposed when all clones of the handle are dropped.
Implementations
Sourceimpl ViewImageHandle
impl ViewImageHandle
Sourcepub fn image_id(&self) -> ImageId
pub fn image_id(&self) -> ImageId
Image ID.
Is ImageId::INVALID for dummy.
Sourcepub fn app_id(&self) -> Option<AppId>
pub fn app_id(&self) -> Option<AppId>
Application that requested this image.
Images can only be used in the same app.
Is None for dummy.
Sourcepub fn view_process_gen(&self) -> ViewProcessGen
pub fn view_process_gen(&self) -> ViewProcessGen
View-process generation that provided this image.
Images can only be used in the same view-process instance.
Is ViewProcessGen::INVALID for dummy.
Sourcepub fn downgrade(&self) -> WeakViewImageHandle
pub fn downgrade(&self) -> WeakViewImageHandle
Create a weak reference to this handle.