ViewRenderer

Struct ViewRenderer 

pub struct ViewRenderer(/* private fields */);
Weak handle to a window or view.

This is only a weak reference, every method returns ChannelError::disconnected if the window is closed or view is disposed.

Implementations

Source

impl ViewRenderer

pub fn generation(&self) -> Result<ViewProcessGen, ChannelError>

Returns the view-process generation on which the renderer was created.

pub fn use_image( &self, image: &ViewImageHandle, ) -> Result<ImageTextureId, ChannelError>

Use an image resource in the window renderer.

Returns the image texture ID.

pub fn update_image_use( &mut self, tex_id: ImageTextureId, image: &ViewImageHandle, dirty_rect: Option<PxRect>, ) -> Result<bool, ChannelError>

Replace the image resource in the window renderer.

The new image handle must represent an image with same dimensions and format as the previous. If the image cannot be updated an error is logged and false is returned.

The dirty_rect can be set to optimize texture upload to the GPU, if not set the entire image region updates.

pub fn delete_image_use( &mut self, tex_id: ImageTextureId, ) -> Result<(), ChannelError>

Delete the image resource in the window renderer.

pub fn add_font_face( &self, bytes: IpcFontBytes, index: u32, ) -> Result<FontFaceId, ChannelError>

Add a raw font resource to the window renderer.

Returns the new font face ID, unique for this renderer.

pub fn delete_font_face( &self, font_face_id: FontFaceId, ) -> Result<(), ChannelError>

Delete the font resource in the window renderer.

pub fn add_font( &self, font_face_id: FontFaceId, glyph_size: Px, options: FontOptions, variations: Vec<(FontVariationName, f32)>, ) -> Result<FontId, ChannelError>

Add a sized font to the window renderer.

Returns the new font ID, unique for this renderer.

pub fn delete_font(&self, font_id: FontId) -> Result<(), ChannelError>

Delete the sized font.

pub fn frame_image( &self, mask: Option<ImageMaskMode>, ) -> Result<ViewImageHandle, ChannelError>

Create a new image resource from the current rendered frame.

pub fn frame_image_rect( &self, rect: PxRect, mask: Option<ImageMaskMode>, ) -> Result<ViewImageHandle, ChannelError>

Create a new image resource from a selection of the current rendered frame.

pub fn render(&self, frame: FrameRequest) -> Result<(), ChannelError>

Render a new frame.

pub fn render_update( &self, frame: FrameUpdateRequest, ) -> Result<(), ChannelError>

Update the current frame and re-render it.

pub fn render_extension_raw( &self, extension_id: ApiExtensionId, request: ApiExtensionPayload, ) -> Result<ApiExtensionPayload, ChannelError>

Call a render extension with custom encoded payload.

pub fn render_extension<I, O>( &self, extension_id: ApiExtensionId, request: &I, ) -> Result<Result<O, ApiExtensionRecvError>, ChannelError>

Call a render extension with serialized payload.