pub struct WeakViewAudioHandle(/* private fields */);Expand description
Connection to an audio loading or loaded in the View Process.
The audio is removed from the View Process cache when all clones of ViewAudioHandle drops, but
if there is another audio pointer holding it, this weak pointer can be upgraded back
to a strong connection to the audio.
Dummy handles never upgrade back.
Implementations
Sourceimpl WeakViewAudioHandle
impl WeakViewAudioHandle
Sourcepub fn upgrade(&self) -> Option<ViewAudioHandle>
pub fn upgrade(&self) -> Option<ViewAudioHandle>
Attempt to upgrade the weak pointer to the audio to a full audio.
Returns Some if the is at least another ViewAudioHandle holding the audio alive.