pub struct WeakViewImageHandle(/* private fields */);Expand description
Connection to an image loading or loaded in the View Process.
The image is removed from the View Process cache when all clones of ViewImageHandle drops, but
if there is another image pointer holding the image, this weak pointer can be upgraded back
to a strong connection to the image.
Dummy handles never upgrade back.
Implementations
Sourceimpl WeakViewImageHandle
impl WeakViewImageHandle
Sourcepub fn upgrade(&self) -> Option<ViewImageHandle>
pub fn upgrade(&self) -> Option<ViewImageHandle>
Attempt to upgrade the weak pointer to the image to a full image.
Returns Some if the is at least another ViewImageHandle holding the image alive.