#[non_exhaustive]pub struct WindowOpenData {
pub state: WindowStateAll,
pub monitor: Option<MonitorId>,
pub position: (PxPoint, DipPoint),
pub size: DipSize,
pub scale_factor: Factor,
pub refresh_rate: Frequency,
pub render_mode: RenderMode,
pub safe_padding: DipSideOffsets,
}Expand description
Information about a successfully opened window.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.state: WindowStateAllWindow complete state.
monitor: Option<MonitorId>Monitor that contains the window.
position: (PxPoint, DipPoint)Actual top-left offset of the window (excluding outer chrome).
The values are the global position and the position in the monitor.
size: DipSizeActual dimensions of the client area of the window (excluding outer chrome).
scale_factor: FactorActual scale factor.
refresh_rate: FrequencyActual refresh rate used for the window, in millihertz.
render_mode: RenderModeActual render mode, can be different from the requested mode if it is not available.
safe_padding: DipSideOffsetsPadding that must be applied to the window content so that it stays clear of screen obstructions such as a camera notch cutout.
Note that the unsafe area must still be rendered as it may be partially visible, just don’t place nay interactive or important content outside of this padding.