Function zng_app::widget::node::match_node_list
source · pub fn match_node_list<L: UiNodeList>(
children: L,
closure: impl FnMut(&mut MatchNodeChildren<L>, UiNodeOp<'_>) + Send + 'static
) -> impl UiNodeExpand description
Creates a node that is implemented as a closure that matches over UiNodeOp and delegates to multiple children nodes in a list.
The closure node can delegate to children, when the closure itself does not delegate, the children methods
are called after the closure returns. See MatchNodeChildren for more details.