pub struct MatchNodeChild { /* private fields */ }Expand description
Child node of match_node.
When the closure does not delegate to this node the delegation happens after the closure returns.
Implementations
Sourceimpl MatchNodeChild
impl MatchNodeChild
Sourcepub fn delegated(&mut self)
pub fn delegated(&mut self)
Flags the current operation as delegated, stopping the default delegation after the closure ends.
Note that each node operation methods already flags this.
Sourcepub fn has_delegated(&self) -> bool
pub fn has_delegated(&self) -> bool
If the current operation was already delegated to the child.
Sourcepub fn node(&mut self) -> &mut UiNode
pub fn node(&mut self) -> &mut UiNode
Borrow the actual child.
Note that if you delegate using this reference you must call delegated.
Sourcepub fn node_impl<U: UiNodeImpl>(&mut self) -> &mut U
pub fn node_impl<U: UiNodeImpl>(&mut self) -> &mut U
Sourcepub fn init(&mut self)
pub fn init(&mut self)
Delegate UiNode::init.
Sourcepub fn deinit(&mut self)
pub fn deinit(&mut self)
Delegate UiNode::deinit.
Sourcepub fn info(&mut self, info: &mut WidgetInfoBuilder)
pub fn info(&mut self, info: &mut WidgetInfoBuilder)
Delegate UiNode::info.
Sourcepub fn update(&mut self, updates: &WidgetUpdates)
pub fn update(&mut self, updates: &WidgetUpdates)
Delegate UiNode::update.
Sourcepub fn update_list(
&mut self,
updates: &WidgetUpdates,
observer: &mut dyn UiNodeListObserver,
)
pub fn update_list( &mut self, updates: &WidgetUpdates, observer: &mut dyn UiNodeListObserver, )
Delegate UiNode::update_list.
Sourcepub fn measure(&mut self, wm: &mut WidgetMeasure) -> PxSize
pub fn measure(&mut self, wm: &mut WidgetMeasure) -> PxSize
Delegate UiNode::measure.
Sourcepub fn measure_list(
&mut self,
wm: &mut WidgetMeasure,
measure: impl Fn(usize, &mut UiNode, &mut WidgetMeasure) -> PxSize + Sync,
fold_size: impl Fn(PxSize, PxSize) -> PxSize + Sync,
) -> PxSize
pub fn measure_list( &mut self, wm: &mut WidgetMeasure, measure: impl Fn(usize, &mut UiNode, &mut WidgetMeasure) -> PxSize + Sync, fold_size: impl Fn(PxSize, PxSize) -> PxSize + Sync, ) -> PxSize
Delegate UiNode::measure_list.
Sourcepub fn layout(&mut self, wl: &mut WidgetLayout) -> PxSize
pub fn layout(&mut self, wl: &mut WidgetLayout) -> PxSize
Delegate UiNode::layout.
Sourcepub fn layout_list(
&mut self,
wl: &mut WidgetLayout,
layout: impl Fn(usize, &mut UiNode, &mut WidgetLayout) -> PxSize + Sync,
fold_size: impl Fn(PxSize, PxSize) -> PxSize + Sync,
) -> PxSize
pub fn layout_list( &mut self, wl: &mut WidgetLayout, layout: impl Fn(usize, &mut UiNode, &mut WidgetLayout) -> PxSize + Sync, fold_size: impl Fn(PxSize, PxSize) -> PxSize + Sync, ) -> PxSize
Delegate UiNode::layout_list.
Sourcepub fn render(&mut self, frame: &mut FrameBuilder)
pub fn render(&mut self, frame: &mut FrameBuilder)
Delegate UiNode::render.
Sourcepub fn render_list(
&mut self,
frame: &mut FrameBuilder,
render: impl Fn(usize, &mut UiNode, &mut FrameBuilder) + Sync,
)
pub fn render_list( &mut self, frame: &mut FrameBuilder, render: impl Fn(usize, &mut UiNode, &mut FrameBuilder) + Sync, )
Delegate UiNode::render_list.
Sourcepub fn render_update(&mut self, update: &mut FrameUpdate)
pub fn render_update(&mut self, update: &mut FrameUpdate)
Delegate UiNode::render_update.
Sourcepub fn render_update_list(
&mut self,
update: &mut FrameUpdate,
render_update: impl Fn(usize, &mut UiNode, &mut FrameUpdate) + Sync,
)
pub fn render_update_list( &mut self, update: &mut FrameUpdate, render_update: impl Fn(usize, &mut UiNode, &mut FrameUpdate) + Sync, )
Delegate UiNode::render_update_list.
Sourcepub fn op(&mut self, op: UiNodeOp<'_>)
pub fn op(&mut self, op: UiNodeOp<'_>)
Delegate UiNode::op.