AnyEventArgs

Trait AnyEventArgs 

pub trait AnyEventArgs: AnyVarValue {
    // Required methods
    fn timestamp(&self) -> DInstant;
    fn propagation(&self) -> &EventPropagationHandle;
    fn is_in_target(&self, widget: WidgetId) -> bool;
    fn clone_boxed(&self) -> Box<dyn AnyEventArgs>;
}
Represents any event update.

Required Methods

fn timestamp(&self) -> DInstant

Instant this event update happened.

fn propagation(&self) -> &EventPropagationHandle

Propagation handle associated with this event instance.

Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.

fn is_in_target(&self, widget: WidgetId) -> bool

Gets if the widget is in any of the target paths in this update.

fn clone_boxed(&self) -> Box<dyn AnyEventArgs>

Clone the args to a new box.

Implementors

Source

impl AnyEventArgs for AccessClickArgs

Source

impl AnyEventArgs for AccessDeinitedArgs

Source

impl AnyEventArgs for AccessExpanderArgs

Source

impl AnyEventArgs for AccessFocusArgs

Source

impl AnyEventArgs for AccessFocusNavOriginArgs

Source

impl AnyEventArgs for AccessIncrementArgs

Source

impl AnyEventArgs for AccessInitedArgs

Source

impl AnyEventArgs for AccessNumberArgs

Source

impl AnyEventArgs for AccessScrollArgs

Source

impl AnyEventArgs for AccessSelectionArgs

Source

impl AnyEventArgs for AccessTextArgs

Source

impl AnyEventArgs for AccessToolTipArgs

Source

impl AnyEventArgs for ExitRequestedArgs

Source

impl AnyEventArgs for AxisMotionArgs

Source

impl AnyEventArgs for ButtonArgs

Source

impl AnyEventArgs for InputDevicesChangedArgs

Source

impl AnyEventArgs for KeyArgs

Source

impl AnyEventArgs for PointerMotionArgs

Source

impl AnyEventArgs for ScrollMotionArgs

Source

impl AnyEventArgs for LowMemoryArgs

Source

impl AnyEventArgs for RawAnimationsConfigChangedArgs

Source

impl AnyEventArgs for RawAppDragEndedArgs

Source

impl AnyEventArgs for RawAudioDecodeErrorArgs

Source

impl AnyEventArgs for RawAudioDecodedArgs

Source

impl AnyEventArgs for RawAudioMetadataDecodedArgs

Source

impl AnyEventArgs for RawAudioOutputOpenArgs

Source

impl AnyEventArgs for RawAudioOutputOpenErrorArgs

Source

impl AnyEventArgs for RawAxisMotionArgs

Source

impl AnyEventArgs for RawColorsConfigChangedArgs

Source

impl AnyEventArgs for RawDragCancelledArgs

Source

impl AnyEventArgs for RawDragDroppedArgs

Source

impl AnyEventArgs for RawDragHoveredArgs

Source

impl AnyEventArgs for RawDragMovedArgs

Source

impl AnyEventArgs for RawExtensionEventArgs

Source

impl AnyEventArgs for RawFontAaChangedArgs

Source

impl AnyEventArgs for RawFontChangedArgs

Source

impl AnyEventArgs for RawFrameRenderedArgs

Source

impl AnyEventArgs for RawHeadlessOpenArgs

Source

impl AnyEventArgs for RawImageDecodeErrorArgs

Source

impl AnyEventArgs for RawImageDecodedArgs

Source

impl AnyEventArgs for RawImageMetadataDecodedArgs

Source

impl AnyEventArgs for RawImeArgs

Source

impl AnyEventArgs for RawKeyInputArgs

Source

impl AnyEventArgs for RawKeyRepeatConfigChangedArgs

Source

impl AnyEventArgs for RawLocaleChangedArgs

Source

impl AnyEventArgs for RawMonitorsChangedArgs

Source

impl AnyEventArgs for RawMouseArgs

Source

impl AnyEventArgs for RawMouseInputArgs

Source

impl AnyEventArgs for RawMouseMovedArgs

Source

impl AnyEventArgs for RawMouseWheelArgs

Source

impl AnyEventArgs for RawMultiClickConfigChangedArgs

Source

impl AnyEventArgs for RawScaleFactorChangedArgs

Source

impl AnyEventArgs for RawTouchArgs

Source

impl AnyEventArgs for RawTouchConfigChangedArgs

Source

impl AnyEventArgs for RawTouchpadPressureArgs

Source

impl AnyEventArgs for RawWindowChangedArgs

Source

impl AnyEventArgs for RawWindowCloseArgs

Source

impl AnyEventArgs for RawWindowCloseRequestedArgs

Source

impl AnyEventArgs for RawWindowFocusArgs

Source

impl AnyEventArgs for RawWindowOpenArgs

Source

impl AnyEventArgs for RawWindowOrHeadlessOpenErrorArgs

Source

impl AnyEventArgs for ViewProcessInitedArgs

Source

impl AnyEventArgs for ViewProcessSuspendedArgs

Source

impl AnyEventArgs for WidgetTreeChangedArgs

Source

impl AnyEventArgs for CommandArgs