pub trait AnyEventArgs: AnyVarValue {
// Required methods
fn timestamp(&self) -> DInstant;
fn propagation(&self) -> &EventPropagationHandle;
fn is_in_target(&self, widget: WidgetId) -> bool;
fn clone_boxed(&self) -> Box<dyn AnyEventArgs>;
}Expand description
Represents any event update.
Required Methods
Sourcefn propagation(&self) -> &EventPropagationHandle
fn propagation(&self) -> &EventPropagationHandle
Propagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Sourcefn is_in_target(&self, widget: WidgetId) -> bool
fn is_in_target(&self, widget: WidgetId) -> bool
Gets if the widget is in any of the target paths in this update.
Sourcefn clone_boxed(&self) -> Box<dyn AnyEventArgs>
fn clone_boxed(&self) -> Box<dyn AnyEventArgs>
Clone the args to a new box.