pub struct RawFrameRenderedArgs {
pub timestamp: DInstant,
pub window_id: WindowId,
pub frame_id: FrameId,
pub frame_image: Option<WeakEq<(ViewImageHandle, ImageDecoded)>>,
pub propagation: EventPropagationHandle,
}Expand description
Arguments for the RAW_FRAME_RENDERED_EVENT.
Fields
timestamp: DInstantInstant the event happened.
window_id: WindowIdWindow that presents the rendered frame.
frame_id: FrameIdFrame tag.
frame_image: Option<WeakEq<(ViewImageHandle, ImageDecoded)>>The frame pixels if it was requested when the frame request was sent to the view process.
The handle can be upgraded on hook only, after it is dropped. This is so the latest event does not keep the image alive indefinitely.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations
Sourceimpl RawFrameRenderedArgs
impl RawFrameRenderedArgs
Sourcepub fn new(
timestamp: impl Into<DInstant>,
propagation: EventPropagationHandle,
window_id: impl Into<WindowId>,
frame_id: impl Into<FrameId>,
frame_image: impl Into<Option<WeakEq<(ViewImageHandle, ImageDecoded)>>>,
) -> Self
pub fn new( timestamp: impl Into<DInstant>, propagation: EventPropagationHandle, window_id: impl Into<WindowId>, frame_id: impl Into<FrameId>, frame_image: impl Into<Option<WeakEq<(ViewImageHandle, ImageDecoded)>>>, ) -> Self
New args from values that convert into the argument types.