pub struct RawHeadlessOpenArgs {
pub timestamp: DInstant,
pub window_id: WindowId,
pub surface: WeakViewHeadless,
pub data: HeadlessOpenData,
pub propagation: EventPropagationHandle,
}Expand description
Arguments for the RAW_HEADLESS_OPEN_EVENT.
Fields
timestamp: DInstantInstant the event happened.
window_id: WindowIdWindow id that represents the headless surface that finished opening.
surface: WeakViewHeadlessLive connection to the headless surface in the view-process.
The handle can be upgraded on hook only, after it is dropped. This is so the latest event does not keep the surface alive indefinitely.
data: HeadlessOpenDataExtra data send by the view-process.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations
Sourceimpl RawHeadlessOpenArgs
impl RawHeadlessOpenArgs
Sourcepub fn new(
timestamp: impl Into<DInstant>,
propagation: EventPropagationHandle,
window_id: impl Into<WindowId>,
surface: impl Into<WeakViewHeadless>,
data: impl Into<HeadlessOpenData>,
) -> Self
pub fn new( timestamp: impl Into<DInstant>, propagation: EventPropagationHandle, window_id: impl Into<WindowId>, surface: impl Into<WeakViewHeadless>, data: impl Into<HeadlessOpenData>, ) -> Self
New args from values that convert into the argument types.
Sourcepub fn now(
window_id: impl Into<WindowId>,
surface: impl Into<WeakViewHeadless>,
data: impl Into<HeadlessOpenData>,
) -> Self
pub fn now( window_id: impl Into<WindowId>, surface: impl Into<WeakViewHeadless>, data: impl Into<HeadlessOpenData>, ) -> Self
Arguments for event that happened now (INSTANT.now).