pub struct RawKeyInputArgs {
pub timestamp: DInstant,
pub window_id: WindowId,
pub device_id: InputDeviceId,
pub key_code: KeyCode,
pub key_location: KeyLocation,
pub state: KeyState,
pub key: Key,
pub key_modified: Key,
pub text: Txt,
pub propagation: EventPropagationHandle,
}Expand description
Arguments for the RAW_KEY_INPUT_EVENT.
Fields
timestamp: DInstantInstant the event happened.
window_id: WindowIdWindow that received the event.
device_id: InputDeviceIdKeyboard device that generated the event.
key_code: KeyCodePhysical key.
key_location: KeyLocationThe location of the key on the keyboard.
state: KeyStateIf the key was pressed or released.
key: KeySemantic key.
Pressing Shift+A key will produce Key::Char('a') in QWERTY keyboards, the modifiers are not applied.
key_modified: KeySemantic key modified by the current active modifiers.
Pressing Shift+A key will produce Key::Char('A') in QWERTY keyboards, the modifiers are applied.
text: TxtText typed.
This is only set for KeyState::Pressed of a key that generates text.
This is usually the key_modified char, but is also '\r' for Key::Enter. On Windows when a dead key was
pressed earlier but cannot be combined with the character from this key press, the produced text
will consist of two characters: the dead-key-character followed by the character resulting from this key press.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations
Sourceimpl RawKeyInputArgs
impl RawKeyInputArgs
Sourcepub fn new(
timestamp: impl Into<DInstant>,
propagation: EventPropagationHandle,
window_id: impl Into<WindowId>,
device_id: impl Into<InputDeviceId>,
key_code: impl Into<KeyCode>,
key_location: impl Into<KeyLocation>,
state: impl Into<KeyState>,
key: impl Into<Key>,
key_modified: impl Into<Key>,
text: impl Into<Txt>,
) -> Self
pub fn new( timestamp: impl Into<DInstant>, propagation: EventPropagationHandle, window_id: impl Into<WindowId>, device_id: impl Into<InputDeviceId>, key_code: impl Into<KeyCode>, key_location: impl Into<KeyLocation>, state: impl Into<KeyState>, key: impl Into<Key>, key_modified: impl Into<Key>, text: impl Into<Txt>, ) -> Self
New args from values that convert into the argument types.
Sourcepub fn now(
window_id: impl Into<WindowId>,
device_id: impl Into<InputDeviceId>,
key_code: impl Into<KeyCode>,
key_location: impl Into<KeyLocation>,
state: impl Into<KeyState>,
key: impl Into<Key>,
key_modified: impl Into<Key>,
text: impl Into<Txt>,
) -> Self
pub fn now( window_id: impl Into<WindowId>, device_id: impl Into<InputDeviceId>, key_code: impl Into<KeyCode>, key_location: impl Into<KeyLocation>, state: impl Into<KeyState>, key: impl Into<Key>, key_modified: impl Into<Key>, text: impl Into<Txt>, ) -> Self
Arguments for event that happened now (INSTANT.now).