pub struct RawMouseMovedArgs {
pub timestamp: DInstant,
pub window_id: WindowId,
pub device_id: InputDeviceId,
pub coalesced_pos: Vec<DipPoint>,
pub position: DipPoint,
pub propagation: EventPropagationHandle,
}Expand description
Arguments for the RAW_MOUSE_MOVED_EVENT.
Fields
timestamp: DInstantInstant the event happened.
window_id: WindowIdWindow the mouse was moved over.
device_id: InputDeviceIdDevice that generated this event.
coalesced_pos: Vec<DipPoint>Positions of the mouse in between the previous event and this one.
Mouse move events can be coalesced, i.e. multiple mouse moves packed into a single event.
position: DipPointPosition of the mouse over the window, (0, 0) is the top-left.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations
Sourceimpl RawMouseMovedArgs
impl RawMouseMovedArgs