VIEW_PROCESS

Struct VIEW_PROCESS 

pub struct VIEW_PROCESS;
Connection to the running view-process for the context app.

Implementations

Source

impl VIEW_PROCESS

pub fn is_available(&self) -> bool

If the VIEW_PROCESS can be used, this is only true in app threads for apps with render, all other methods will panic if called when this is not true.

pub fn is_connected(&self) -> bool

View-process running, connected and ready.

pub fn is_headless_with_render(&self) -> bool

If is running in headless renderer mode.

pub fn is_same_process(&self) -> bool

If is running both view and app in the same process.

pub fn info(&self) -> MappedRwLockReadGuard<'static, ViewProcessInfo>

Read lock view-process and reference current generation info.

Strongly recommend to clone/copy the info required, as the lock prevents info update on respawn.

pub fn generation(&self) -> ViewProcessGen

Gets the current view-process generation.

pub fn set_device_events_filter( &self, filter: DeviceEventsFilter, ) -> Result<(), ChannelError>

Enable/disable global device events.

This filter affects device events not targeted at windows, such as mouse move outside windows or key presses when the app has no focused window.

pub fn open_window(&self, config: WindowRequest) -> Result<(), ChannelError>

Sends a request to open a window and associate it with the window_id.

A RAW_WINDOW_OPEN_EVENT or RAW_WINDOW_OR_HEADLESS_OPEN_ERROR_EVENT will be received in response to this request.

pub fn open_headless(&self, config: HeadlessRequest) -> Result<(), ChannelError>

Sends a request to open a headless renderer and associate it with the window_id.

Note that no actual window is created, only the renderer, the use of window-ids to identify this renderer is only for convenience.

A RAW_HEADLESS_OPEN_EVENT or RAW_WINDOW_OR_HEADLESS_OPEN_ERROR_EVENT will be received in response to this request.

pub fn open_audio_output( &self, request: AudioOutputRequest, ) -> Result<(), ChannelError>

Send a request to open a connection to an audio output device.

A RAW_AUDIO_OUTPUT_OPEN_EVENT or RAW_AUDIO_OUTPUT_OPEN_ERROR_EVENT

pub fn add_image( &self, request: ImageRequest<IpcBytes>, ) -> Result<ViewImageHandle, ChannelError>

Send an image for decoding and caching.

This function returns immediately, the handle must be held and compared with the RAW_IMAGE_METADATA_DECODED_EVENT, RAW_IMAGE_DECODED_EVENT and RAW_IMAGE_DECODE_ERROR_EVENT events to receive the data.

pub fn add_image_pro( &self, request: ImageRequest<IpcReceiver<IpcBytes>>, ) -> Result<ViewImageHandle, ChannelError>

Starts sending an image for progressive decoding and caching.

This function returns immediately, the handle must be held and compared with the RAW_IMAGE_METADATA_DECODED_EVENT, RAW_IMAGE_DECODED_EVENT and RAW_IMAGE_DECODE_ERROR_EVENT events to receive the data.

pub fn encode_image( &self, request: ImageEncodeRequest, ) -> Receiver<Result<IpcBytes, EncodeError>>

Starts encoding an image.

The returned channel will update once with the result.

pub fn add_audio( &self, request: AudioRequest<IpcBytes>, ) -> Result<ViewAudioHandle, ChannelError>

Send an audio for decoding and caching.

Depending on the request the audio may be decoded entirely or it may be decoded on demand.

This function returns immediately, the handle must be held and compared with the RAW_AUDIO_METADATA_DECODED_EVENT, RAW_AUDIO_DECODED_EVENT and RAW_AUDIO_DECODE_ERROR_EVENT events to receive the metadata and data.

pub fn add_audio_pro( &self, request: AudioRequest<IpcReceiver<IpcBytes>>, ) -> Result<ViewAudioHandle, ChannelError>

Starts sending an audio for decoding and caching.

Depending on the request the audio may be decoded as it is received or it may be decoded on demand.

This function returns immediately, the handle must be held and compared with the RAW_AUDIO_METADATA_DECODED_EVENT, RAW_AUDIO_DECODED_EVENT and RAW_AUDIO_DECODE_ERROR_EVENT events to receive the metadata and data.

pub fn clipboard(&self) -> Result<&ViewClipboard, ChannelError>

View-process clipboard methods.

pub fn notification_dialog( &self, notification: Var<Notification>, responder: ResponderVar<NotificationResponse>, ) -> Result<(), ChannelError>

Register a native notification, either a popup or an entry in the system notifications list.

If the notification var updates the notification content updates or closes.

If the notification is responded the responder variable is set.

pub fn pending_frames(&self) -> usize

Number of frame send that have not finished rendering.

This is the sum of pending frames for all renderers.

pub fn respawn(&self)

Reopen the view-process, causing another Event::Inited.

pub fn extension_id( &self, extension_name: impl Into<ApiExtensionName>, ) -> Result<Option<ApiExtensionId>, ChannelError>

Gets the ID for the extension_name in the current view-process.

The ID can change for every view-process instance, you must subscribe to the VIEW_PROCESS_INITED_EVENT to refresh the ID. The view-process can respawn at any time in case of error.

pub fn third_party_licenses(&self) -> Result<Vec<LicenseUsed>, ChannelError>

Licenses that may be required to be displayed in the app about screen.

This is specially important for prebuilt view users, as the tools that scrap licenses may not find the prebuilt dependencies.

pub fn app_extension_raw( &self, extension_id: ApiExtensionId, extension_request: ApiExtensionPayload, ) -> Result<ApiExtensionPayload, ChannelError>

Call an extension with custom encoded payload.

pub fn app_extension<I, O>( &self, extension_id: ApiExtensionId, request: &I, ) -> Result<Result<O, ApiExtensionRecvError>, ChannelError>

Call an extension with payload request.

pub fn handle_disconnect(&self, vp_gen: ViewProcessGen)

Handle an Event::Disconnected.

The process will exit if the view-process was killed by the user.