pub struct ViewAudioHandle(/* private fields */);Expand description
Handle to an audio loading or loaded in the View Process.
The audio is disposed when all clones of the handle are dropped.
Implementations
Sourceimpl ViewAudioHandle
impl ViewAudioHandle
Sourcepub fn audio_id(&self) -> AudioId
pub fn audio_id(&self) -> AudioId
Audio ID.
Is AudioId::INVALID for dummy.
Sourcepub fn app_id(&self) -> Option<AppId>
pub fn app_id(&self) -> Option<AppId>
Application that requested this image.
Audios can only be used in the same app.
Is None for dummy.
Sourcepub fn view_process_gen(&self) -> ViewProcessGen
pub fn view_process_gen(&self) -> ViewProcessGen
View-process generation that provided this image.
Audios can only be used in the same view-process instance.
Is ViewProcessGen::INVALID for dummy.
Sourcepub fn downgrade(&self) -> WeakViewAudioHandle
pub fn downgrade(&self) -> WeakViewAudioHandle
Create a weak reference to this audio.