Function zng_app::widget::node::match_node_leaf
source · pub fn match_node_leaf(
closure: impl FnMut(UiNodeOp<'_>) + Send + 'static
) -> impl UiNodeExpand description
Creates a node that is implemented as a closure that matches over UiNodeOp and does not delegate to any child node.